@@ -1,8 +1,12 @@
 # Copyright 1999-2012 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
 
+import errno
 import io
+import platform
 import stat
+import subprocess
+import tempfile
 import textwrap
 from _emerge.SpawnProcess import SpawnProcess
 from _emerge.EbuildBuildDir import EbuildBuildDir
@@ -12,7 +16,7 @@ from portage.elog import messages as elog_messages
 from portage.localization import _
 from portage.package.ebuild._ipc.ExitCommand import ExitCommand
 from portage.package.ebuild._ipc.QueryCommand import QueryCommand
-from portage import os
+from portage import shutil, os
 from portage.util._pty import _create_pty_or_pipe
 from portage.util import apply_secpass_permissions
 
@@ -20,8 +24,10 @@ class AbstractEbuildProcess(SpawnProcess):
 
 	__slots__ = ('phase', 'settings',) + \
 		('_build_dir', '_ipc_daemon', '_exit_command', '_exit_timeout_id')
+
 	_phases_without_builddir = ('clean', 'cleanrm', 'depend', 'help',)
 	_phases_interactive_whitelist = ('config',)
+	_phases_without_cgroup = ('preinst', 'postinst', 'prerm', 'postrm', 'config')
 
 	# Number of milliseconds to allow natural exit of the ebuild
 	# process after it has called the exit command via IPC. It
@@ -56,9 +62,42 @@ class AbstractEbuildProcess(SpawnProcess):
 			(self.phase, self.settings['PORTAGE_BUILDDIR'])
 			self._eerror(textwrap.wrap(msg, 72))
 			self._set_returncode((self.pid, 1 << 8))
-			self.wait()
+			self._async_wait()
 			return
 
+		# Check if the cgroup hierarchy is in place. If it's not, mount it.
+		if (os.geteuid() == 0 and platform.system() == 'Linux'
+				and 'cgroup' in self.settings.features
+				and self.phase not in self._phases_without_cgroup):
+			cgroup_root = '/sys/fs/cgroup'
+			cgroup_portage = os.path.join(cgroup_root, 'portage')
+
+			try:
+				# cgroup tmpfs
+				if not os.path.ismount(cgroup_root):
+					# we expect /sys/fs to be there already
+					if not os.path.isdir(cgroup_root):
+						os.mkdir(cgroup_root, 0o755)
+					subprocess.check_call(['mount', '-t', 'tmpfs',
+						'-o', 'rw,nosuid,nodev,noexec,mode=0755',
+						'tmpfs', cgroup_root])
+
+				# portage subsystem
+				if not os.path.ismount(cgroup_portage):
+					if not os.path.isdir(cgroup_portage):
+						os.mkdir(cgroup_portage, 0o755)
+					subprocess.check_call(['mount', '-t', 'cgroup',
+						'-o', 'rw,nosuid,nodev,noexec,none,name=portage',
+						'tmpfs', cgroup_portage])
+
+				cgroup_path = tempfile.mkdtemp(dir=cgroup_portage,
+					prefix='%s:%s.' % (self.settings["CATEGORY"],
+					self.settings["PF"]))
+			except (subprocess.CalledProcessError, OSError):
+				pass
+			else:
+				self.cgroup = cgroup_path
+
 		if self.background:
 			# Automatically prevent color codes from showing up in logs,
 			# since we're not displaying to a terminal anyway.
@@ -274,6 +313,13 @@ class AbstractEbuildProcess(SpawnProcess):
 	def _set_returncode(self, wait_retval):
 		SpawnProcess._set_returncode(self, wait_retval)
 
+		if self.cgroup is not None:
+			try:
+				shutil.rmtree(self.cgroup)
+			except EnvironmentError as e:
+				if e.errno != errno.ENOENT:
+					raise
+
 		if self._exit_timeout_id is not None:
 			self.scheduler.source_remove(self._exit_timeout_id)
 			self._exit_timeout_id = None
